;;; color-mate.el -- Coloring mule/emacs to more easier and more fun.

;; Copyright (C) HIROSHI Yokota

;; Author: Hiroshi Yokota <y5t0964@students.chiba-u.ac.jp>
;; Maintainer: Hiroshi Yokota <y5t0964@students.chiba-u.ac.jp>
;; Version: 8.1
;; Keywords: color hilit19 font-lock color-mate
;; Content-Type: text/plain; charset=x-euc-jp

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;
;;   Color-Mate  Ver.8.1
;;         by  ͵ (y5t0964@students.chiba-u.ac.jp)
;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;
;;   Coloring mule/emacs to more easier and more fun.
;;   mule / emacs ǡѤƸ䤹̤ˤޤ
;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;;; Commentary:
;; (1) Add file "color-mate.Xdefaults.add"'s contents to your ~/.Xdefaults.
;; (2) Make color-mate-rgb.el. This file make from rgb.txt and rgb2el.pl
;;     (Perl script).
;; (3) Write these lines to your ~/.emacs
;;        (if (and (>= (string-to-int emacs-version) 19)
;;	           window-system )
;;            (progn
;;               (require 'color-mate)
;;               (color-mate)
;;               ))
;;     or Add "color-mate.emacs.add"'s contents to your ~/.emacs.
;;
;;  If you want to more, see color-mate-face.el.
;;
;;
;; <feature tree>
;; Color-Mate
;;   |
;;   +- color-mate.el
;;   |    +- color-mate-rgb.el
;;   |    +- color-mate-e19.el
;;   |    +- color-mate-xemacs.el
;;   |
;;   +- color-mate-face.el
;;   |    +- <hilit19.el>
;;   |    +- <font-lock.el>
;;   |    +- <paren.el>
;;   |    +- <canna.el>
;;   |    +- <can-n-egg.el>
;;   |
;;   +- kanakan-cursor/skk-cursor.el
;;   +- kanakan-cursor/egg-cursor.el
;;   |    +- <egg.el>
;;   +- kanakan-cursor/canna-cursor.el
;;   |    +- <canna.el>
;;   +- kanakan-cursor/sj3-cursor.el
;;        +- <egg.el>

;$Id: color-mate.el,v 8.7 1997/04/11 07:25:06 qyokota Exp $

;; -*-mode: emacs-lisp-*-

;;; Code:

;;
;; Color-Mate.el
;;

;----------------;
; Сɽ
;----------------;
(defconst color-mate-version-string "Color-Mate Ver.8.0 based on mule 2.3(emacs 19.28.1) / emacs 19.31.1 / xemacs 19.14 : color-mate.el 1996/Mar/01")

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;                       СɽѴؿ
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(defun color-mate-version ()
  "Show Color-Mate version."
  (interactive)
  (message (concat (substring color-mate-version-string 0 72) " ...")) )

;----------------------------------------------------------------------;
;                         Color-Mate ѿ
;----------------------------------------------------------------------;
;; 
; modeline
(defvar color-mate-modeline-underlined nil
  "Modeline underlined (t/nil)")
(defvar color-mate-modeline-background-color "green4"
  "Modeline background color (color name)")
(defvar color-mate-modeline-foreground-color "white"
  "Modeline foreground color (color name)")
(defvar color-mate-modeline-buffer-id-foreground-color "cyan2"
  "Modeline buffer ID color. (ex. \"Mule: *scratch*\") (color name)
This is xemacs only.")
(defvar color-mate-modeline-mousable-foreground-color  "pink"
  "Modeline major mode color. (color name) This is xemacs only.")
(defvar color-mate-modeline-mousable-minor-mode-foreground-color "palegreen"
  "Modeline minor mode color. (color name) This is xemacs only.")

; region
(defvar color-mate-region-underlined nil
  "Region underlined (t/nil)")
(defvar color-mate-region-background-color "white"
  "Region background color (color name)")
(defvar color-mate-region-foreground-color "navy"
  "Region foreground color (color name)")

; frame
(defvar color-mate-frame-background-color "AntiqueWhite"
  "Frame background color (color name)")
(defvar color-mate-frame-foreground-color "black"
  "Frame foreground color (color name)")
(defvar color-mate-frame-height 40
  "Frame height (number)")
(defvar color-mate-frame-width 80
  "Frame width (number)")

; cursor
(defvar color-mate-cursor-color "navy"
  "Cursor color (color name)")

; mouse cursor
(defvar color-mate-mouse-color "red"
  "Mouse cursor color (color name)")

; menu bar
(defvar color-mate-menu-bar-lines 1
  "Use menu bar (1=use/0=not use)")

; font set / font
(defvar color-mate-mule-font "default-fontset"
  "Default font set name (For mule only)")
(defvar color-mate-emacs-font "9x15"
  "Default font name (For emacs/xemacs only)")

; misc
(defvar color-mate-line-space "1+1"
  "Space between text lines -->\"<upper space[pixel]>+<lower space[pixel]>\"")


;; local
(defvar color-mate-frame-alist nil
  "Color-Mate's local alist. Don't use it!")
(defvar color-mate-color-history nil
  "Color history. It is Color-Mate's local variable. Don't use it!")


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;                        ؿ
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
; ؿΡmule/emacs ˿ɤ롣
;
(defun color-mate ()
  "Coloring mule/emacs. You can customize these values.

Mode Line:
color-mate-modeline-underlined       Modeline underlined (t/nil)
color-mate-modeline-background-color Modeline background color. (color name)
color-mate-modeline-foreground-color Modeline foreground color. (color name)

These are xemacs only.
color-mate-modeline-buffer-id-foreground-color
                                     Modeline buffer ID color (color name)
color-mate-modeline-mousable-foreground-color
                                     Modeline major mode color (color name)
color-mate-modeline-mousable-minor-mode-foreground-color
                                     Modeline minor mode color (color name)

Region:
color-mate-region-underlined         Region underlined (t/nil)
color-mate-region-background-color   Region background color (color name)
color-mate-region-foreground-color   Region foreground color (color name)

Frame:
color-mate-frame-background-color    Frame background color (color name)
color-mate-frame-foreground-color    Frame foreground color (color name)
color-mate-frame-height              Frame height (number)
color-mate-frame-width               Frame width (number)

Cursor:
color-mate-cursor-color              Cursor color (color name)

Mouse cursor:
color-mate-mouse-color               Mouse cursor color (color name)

Menu bar:
color-mate-menu-bar-lines            Use menu bar (1=use/0=not use)

Font set / Font:
color-mate-mule-font                 Default font set name (For mule only)
color-mate-emacs-font                Default font name (For emacs only)

Misc:
color-mate-line-space                Space between text lines
color-mate-face-modify               Use modified face with hilit19, font-lock
                                     and colored Canna(mule only).If you use
                                     your own faces, please set nil.


You can also use \"M-x color-mate-set-color\" for testing your own colors.
"
  (interactive)
  (if window-system
      (progn
	(message "Loading Color-Mate coloring system...")

	(color-mate-set-default-frame)
;;	(color-mate-set-current-frame)

	(message "Loading Color-Mate coloring system...done"))
    (progn
      (error "color-mate.el requires window system. stop."))
    )
  )


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;               ե졼δͤ롣
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(defun color-mate-set-default-frame ()
  "Set default settings to coloring."
  (if (and (>= (string-to-int emacs-version) 19)
	   window-system )
      (progn
	(if (boundp 'xemacs-logo)
	    ;; XEmacs λ
	    (progn
	      (require 'color-mate-xemacs)
	      (color-mate-xemacs-set-default-frame))
	  ;; Emacs/Mule λ
	  (progn
	    (require 'color-mate-e19)
	    (color-mate-e19-set-default-frame)))
	)))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;                 ߤΥե졼οѹ롣
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(defun color-mate-set-current-frame ()
  "Coloring current frame."
  (if (and (>= (string-to-int emacs-version) 19)
	   window-system )
      (progn
	(if (boundp 'xemacs-logo)
	    ;; XEmacs λ
	    (progn
	      (require 'color-mate-xemacs)
	      (color-mate-xemacs-set-current-frame))
	  ;; Emacs/Mule λ
	  (progn
	    (require 'color-mate-e19)
	    (color-mate-e19-set-current-frame)))
	)))


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;                  󥿥饯ƥѴؿ
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
; 󥿥饯ƥˤäͤƤ줾ѿ
;  color-mate-set-current-frame ؿˤäƸߤΥե졼ο
; ѹ롣
;
(defun color-mate-set-color ( modeline-bg modeline-fg
			      region-bg   region-fg
			      frame-bg    frame-fg
			      cursor
			      mouse )
  "Change current frame color interactively.
Just press return key to use old value."
  
  ; ͤ롣ͤǥեͤȤɽ롣
  ; TAB, SPACE ˤ˥塼 M-n, M-p ˤλȤǽ
  (interactive
   (progn
     (require 'color-mate-rgb)      ; rgb ơ֥θƤӽФ
     
     (mapcar '(lambda (x)
		(completing-read x color-mate-rgb-table nil nil nil
				 'color-mate-color-history))
	     
	     (list
	      (format "Modeline background color (default %s): "
		      color-mate-modeline-background-color)
	      (format "Modeline foreground color (default %s): "
		      color-mate-modeline-foreground-color)
	      (format "Region background color (default %s): "
		      color-mate-region-background-color)
	      (format "Region foreground color (default %s): "
		      color-mate-region-foreground-color)
	      (format "Frame background color (default %s): "
		      color-mate-frame-background-color)
	      (format "Frame foreground color (default %s): "
		      color-mate-frame-foreground-color)
	      (format "Cursor color (default %s): "
		      color-mate-cursor-color)
	      (format "Mouse cursor name (default %s): "
		      color-mate-mouse-color)
	    ))))
  
  (if (and (>= (string-to-int emacs-version) 19)
	   window-system )
      (progn
 	
	; ͤꤵƤФͤ򡢤ƤʤͤѤ
	(if (not (equal modeline-bg  ""))
	    (setq color-mate-modeline-background-color modeline-bg))
	(if (not (equal modeline-fg  ""))
	    (setq color-mate-modeline-foreground-color modeline-fg))
	
	(if (not (equal region-bg    ""))
	    (setq color-mate-region-background-color   region-bg))
	(if (not (equal region-fg    ""))
	    (setq color-mate-region-foreground-color   region-fg))
	
	(if (not (equal frame-bg     ""))
	    (setq color-mate-frame-background-color    frame-bg))
	(if (not (equal frame-fg     ""))
	    (setq color-mate-frame-foreground-color    frame-fg))
	
	(if (not (equal cursor       ""))
	    (setq color-mate-cursor-color              cursor))
	(if (not (equal mouse        ""))
	    (setq color-mate-mouse-color               mouse))
	
	;; 忧
;;	(color-mate-set-default-frame)
	(color-mate-set-current-frame)
	)
    (progn
      (error "color-mate.el requires window system.")
      )
    )
  )


(provide 'color-mate) ; feature ȤϿ

;;; color-mate.el ends here
